@@ -5,7 +5,7 @@ package Dist::Zilla::PluginBundle::SHANTANU;
 
 # PODNAME: Dist::Zilla::PluginBundle::SHANTANU
 
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -62,6 +62,8 @@ use Dist::Zilla::Plugin::CopyFilesFromBuild;
 use Dist::Zilla::Plugin::CheckMetaResources;
 use Dist::Zilla::Plugin::CheckPrereqsIndexed;
 use Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes;
+use Dist::Zilla::Plugin::ChangelogFromGit::Debian;
+use Dist::Zilla::Plugin::Control::Debian;
 use Dist::Zilla::Plugin::CheckChangesHasContent;
 use Dist::Zilla::Plugin::CheckExtraTests;
 
@@ -365,6 +367,22 @@ sub configure {
                 file_name              => 'Changes',
             }
         ],
+        [
+            'ChangelogFromGit::Debian' => {
+                tag_regexp             => '^release-(\d+\.\d+)$',
+                parse_version_from_tag => 1,
+                file_name              => 'debian/changelog',
+                maintainer_name        => 'Shantanu Bhadoria',
+                maintainer_email       => 'shantanu@cpan.org',
+            }
+        ],
+        [
+            'Control::Debian' => {
+                file_name        => 'debian/control',
+                maintainer_name  => 'Shantanu Bhadoria',
+                maintainer_email => 'shantanu@cpan.org',
+            }
+        ],
 
         # build system
         'ExecDir',     # core
@@ -469,7 +487,7 @@ Dist::Zilla::PluginBundle::SHANTANU - Dist Zilla Plugin Bundle the way I like to
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
